(changelog)=
# Changelog

Here you will find an index of the changelogs for all versions that a changelog is available for.

If you think anything is missing, make a pull request to add it, or contact thomm.o on discord.

----

::::{grid} 1 2 2 2
:gutter: 3

:::{grid-item-card} {material-outlined}`new_releases;2em` Version 3
:link: changelogs/v3-changelog
:link-type: doc

Changelog for current versions - `3.0.0` and newer.
:::

:::{grid-item-card} Version 2
:link: changelogs/v2-changelog
:link-type: doc

Changelog for versions since `2.0.0`.
:::

:::{grid-item-card} Version 1
:link: changelogs/v1-changelog
:link-type: doc

Changelog for versions since `1.0.0`.
:::

:::{grid-item-card} Version 0
:link: changelogs/v0-changelog
:link-type: doc

Changelog for versions since `0.0.39`.
:::
::::

:::{toctree}
:hidden:
:maxdepth: 2

changelogs/v3-changelog
changelogs/v2-changelog
changelogs/v1-changelog
changelogs/v0-changelog
:::
